<?php
/**
 * Must Read Posts Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add Must Read Posts section
$wp_customize->add_section( 'blog_diary_pro_must_read_posts_section', array(
	'title'             => esc_html__( 'Must Read Posts ','blog-diary-pro' ),
	'description'       => esc_html__( 'Must Read Posts Section options.', 'blog-diary-pro' ),
	'panel'             => 'blog_diary_pro_front_page_panel',
) );

// Must Read Posts content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_section_enable]', array(
	'default'			=> 	$options['must_read_posts_section_enable'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[must_read_posts_section_enable]', array(
	'label'             => esc_html__( 'Must Read Posts Section Enable', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_must_read_posts_section',
	'on_off_label' 		=> blog_diary_pro_switch_options(),
) ) );

// must_read_posts title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['must_read_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[must_read_posts_title]', array(
	'label'           	=> esc_html__( 'Title', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_must_read_posts_section',
	'active_callback' 	=> 'blog_diary_pro_is_must_read_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[must_read_posts_title]', array(
		'selector'            => '#must-read .section-header h2.section-title',
		'settings'            => 'blog_diary_pro_theme_options[must_read_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_diary_pro_must_read_posts_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_count]', array(
	'default'          	=> $options['must_read_posts_count'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_number_range',
	'validate_callback' => 'blog_diary_pro_validate_must_read_posts_count',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[must_read_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'blog-diary-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_must_read_posts_section',
	'active_callback'   => 'blog_diary_pro_is_must_read_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Must Read Posts column control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_column]', array(
	'default'          	=> $options['must_read_posts_column'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[must_read_posts_column]', array(
	'label'             => esc_html__( 'Column Number', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_must_read_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blog_diary_pro_is_must_read_posts_section_enable',
	'choices'			=> array( 
		2 		=> esc_html__( 'Two Column', 'blog-diary-pro' ),
		3 		=> esc_html__( 'Three Column', 'blog-diary-pro' ),
	),
) );

// Must Read Posts content type control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]', array(
	'default'          	=> $options['must_read_posts_content_type'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[must_read_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_must_read_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blog_diary_pro_is_must_read_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'blog-diary-pro' ),
		'post' 		=> esc_html__( 'Post', 'blog-diary-pro' ),
		'category' 	=> esc_html__( 'Category', 'blog-diary-pro' ),
	),
) );

for ( $i = 1; $i <= $options['must_read_posts_count']; $i++ ) :
	// Must Read pages drop down chooser control and setting
	$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'blog_diary_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[must_read_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'blog-diary-pro' ), $i ),
		'section'           => 'blog_diary_pro_must_read_posts_section',
		'choices'			=> blog_diary_pro_page_choices(),
		'active_callback'	=> 'blog_diary_pro_is_must_read_posts_section_content_page_enable',
	) ) );

	// Must Read posts drop down chooser control and setting
	$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'blog_diary_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[must_read_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'blog-diary-pro' ), $i ),
		'section'           => 'blog_diary_pro_must_read_posts_section',
		'choices'			=> blog_diary_pro_post_choices(),
		'active_callback'	=> 'blog_diary_pro_is_must_read_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blog_diary_pro_theme_options[must_read_posts_content_category]', array(
	'sanitize_callback' => 'blog_diary_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blog_diary_pro_theme_options[must_read_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'blog-diary-pro' ),
	'description'      	=> esc_html__( 'Note: latest selected no of posts will be shown from selected category', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_must_read_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'blog_diary_pro_is_must_read_posts_section_content_category_enable'
) ) );

// must_read_posts btn title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[must_read_posts_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['must_read_posts_btn_title'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[must_read_posts_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_must_read_posts_section',
	'active_callback' 	=> 'blog_diary_pro_is_must_read_posts_section_enable',
	'type'				=> 'text',
) );
